@charset "UTF-8";
@import url("https://fonts.googleapis.com/css?family=Inconsolata:400,700|Lato:300,400,400i,700,900");
/*! Karma-CSS v1.9.5 MIT License | http://karmacss.com | https://github.com/accentdesign/karma-css */
.container{
  padding-right:15px;
  padding-left:15px;
  margin-right:auto;
  margin-left:auto;
}

@media (min-width: 576px){
  .container{
    width:540px;
    max-width:100%;
  }
}

@media (min-width: 768px){
  .container{
    width:720px;
    max-width:100%;
  }
}

@media (min-width: 992px){
  .container{
    width:960px;
    max-width:100%;
  }
}

@media (min-width: 1200px){
  .container{
    width:1140px;
    max-width:100%;
  }
}

.container-fluid{
  width:100%;
  padding-right:15px;
  padding-left:15px;
  margin-right:auto;
  margin-left:auto;
}

.row{
  display:-ms-flexbox;
  display:flex;
  -ms-flex-wrap:wrap;
  flex-wrap:wrap;
  margin-right:-15px;
  margin-left:-15px;
}

.no-gutters{
  margin-right:0;
  margin-left:0;
}

.no-gutters > .col,
.no-gutters > [class*="col-"]{
  padding-right:0;
  padding-left:0;
}

.col-1, .col-2, .col-3, .col-4, .col-5, .col-6, .col-7, .col-8, .col-9, .col-10, .col-11, .col-12, .col,
.col-auto, .col-sm-1, .col-sm-2, .col-sm-3, .col-sm-4, .col-sm-5, .col-sm-6, .col-sm-7, .col-sm-8, .col-sm-9, .col-sm-10, .col-sm-11, .col-sm-12, .col-sm,
.col-sm-auto, .col-md-1, .col-md-2, .col-md-3, .col-md-4, .col-md-5, .col-md-6, .col-md-7, .col-md-8, .col-md-9, .col-md-10, .col-md-11, .col-md-12, .col-md,
.col-md-auto, .col-lg-1, .col-lg-2, .col-lg-3, .col-lg-4, .col-lg-5, .col-lg-6, .col-lg-7, .col-lg-8, .col-lg-9, .col-lg-10, .col-lg-11, .col-lg-12, .col-lg,
.col-lg-auto, .col-xl-1, .col-xl-2, .col-xl-3, .col-xl-4, .col-xl-5, .col-xl-6, .col-xl-7, .col-xl-8, .col-xl-9, .col-xl-10, .col-xl-11, .col-xl-12, .col-xl,
.col-xl-auto{
  width:100%;
  min-height:1px;
  padding-right:15px;
  padding-left:15px;
}

.col{
  -ms-flex-preferred-size:0;
  flex-basis:0;
  -ms-flex-positive:1;
  flex-grow:1;
  max-width:100%;
}

.col-auto{
  -ms-flex:0 0 auto;
  flex:0 0 auto;
  width:auto;
  max-width:none;
}

.col-1{
  -ms-flex:0 0 8.333333%;
  flex:0 0 8.333333%;
  max-width:8.333333%;
}

.col-2{
  -ms-flex:0 0 16.666667%;
  flex:0 0 16.666667%;
  max-width:16.666667%;
}

.col-3{
  -ms-flex:0 0 25%;
  flex:0 0 25%;
  max-width:25%;
}

.col-4{
  -ms-flex:0 0 33.333333%;
  flex:0 0 33.333333%;
  max-width:33.333333%;
}

.col-5{
  -ms-flex:0 0 41.666667%;
  flex:0 0 41.666667%;
  max-width:41.666667%;
}

.col-6{
  -ms-flex:0 0 50%;
  flex:0 0 50%;
  max-width:50%;
}

.col-7{
  -ms-flex:0 0 58.333333%;
  flex:0 0 58.333333%;
  max-width:58.333333%;
}

.col-8{
  -ms-flex:0 0 66.666667%;
  flex:0 0 66.666667%;
  max-width:66.666667%;
}

.col-9{
  -ms-flex:0 0 75%;
  flex:0 0 75%;
  max-width:75%;
}

.col-10{
  -ms-flex:0 0 83.333333%;
  flex:0 0 83.333333%;
  max-width:83.333333%;
}

.col-11{
  -ms-flex:0 0 91.666667%;
  flex:0 0 91.666667%;
  max-width:91.666667%;
}

.col-12{
  -ms-flex:0 0 100%;
  flex:0 0 100%;
  max-width:100%;
}

.order-1{
  -ms-flex-order:1;
  order:1;
}

.order-2{
  -ms-flex-order:2;
  order:2;
}

.order-3{
  -ms-flex-order:3;
  order:3;
}

.order-4{
  -ms-flex-order:4;
  order:4;
}

.order-5{
  -ms-flex-order:5;
  order:5;
}

.order-6{
  -ms-flex-order:6;
  order:6;
}

.order-7{
  -ms-flex-order:7;
  order:7;
}

.order-8{
  -ms-flex-order:8;
  order:8;
}

.order-9{
  -ms-flex-order:9;
  order:9;
}

.order-10{
  -ms-flex-order:10;
  order:10;
}

.order-11{
  -ms-flex-order:11;
  order:11;
}

.order-12{
  -ms-flex-order:12;
  order:12;
}

.offset-1{
  margin-left:8.333333%;
}

.offset-2{
  margin-left:16.666667%;
}

.offset-3{
  margin-left:25%;
}

.offset-4{
  margin-left:33.333333%;
}

.offset-5{
  margin-left:41.666667%;
}

.offset-6{
  margin-left:50%;
}

.offset-7{
  margin-left:58.333333%;
}

.offset-8{
  margin-left:66.666667%;
}

.offset-9{
  margin-left:75%;
}

.offset-10{
  margin-left:83.333333%;
}

.offset-11{
  margin-left:91.666667%;
}

@media (min-width: 576px){
  .col-sm{
    -ms-flex-preferred-size:0;
    flex-basis:0;
    -ms-flex-positive:1;
    flex-grow:1;
    max-width:100%;
  }
  .col-sm-auto{
    -ms-flex:0 0 auto;
    flex:0 0 auto;
    width:auto;
    max-width:none;
  }
  .col-sm-1{
    -ms-flex:0 0 8.333333%;
    flex:0 0 8.333333%;
    max-width:8.333333%;
  }
  .col-sm-2{
    -ms-flex:0 0 16.666667%;
    flex:0 0 16.666667%;
    max-width:16.666667%;
  }
  .col-sm-3{
    -ms-flex:0 0 25%;
    flex:0 0 25%;
    max-width:25%;
  }
  .col-sm-4{
    -ms-flex:0 0 33.333333%;
    flex:0 0 33.333333%;
    max-width:33.333333%;
  }
  .col-sm-5{
    -ms-flex:0 0 41.666667%;
    flex:0 0 41.666667%;
    max-width:41.666667%;
  }
  .col-sm-6{
    -ms-flex:0 0 50%;
    flex:0 0 50%;
    max-width:50%;
  }
  .col-sm-7{
    -ms-flex:0 0 58.333333%;
    flex:0 0 58.333333%;
    max-width:58.333333%;
  }
  .col-sm-8{
    -ms-flex:0 0 66.666667%;
    flex:0 0 66.666667%;
    max-width:66.666667%;
  }
  .col-sm-9{
    -ms-flex:0 0 75%;
    flex:0 0 75%;
    max-width:75%;
  }
  .col-sm-10{
    -ms-flex:0 0 83.333333%;
    flex:0 0 83.333333%;
    max-width:83.333333%;
  }
  .col-sm-11{
    -ms-flex:0 0 91.666667%;
    flex:0 0 91.666667%;
    max-width:91.666667%;
  }
  .col-sm-12{
    -ms-flex:0 0 100%;
    flex:0 0 100%;
    max-width:100%;
  }
  .order-sm-1{
    -ms-flex-order:1;
    order:1;
  }
  .order-sm-2{
    -ms-flex-order:2;
    order:2;
  }
  .order-sm-3{
    -ms-flex-order:3;
    order:3;
  }
  .order-sm-4{
    -ms-flex-order:4;
    order:4;
  }
  .order-sm-5{
    -ms-flex-order:5;
    order:5;
  }
  .order-sm-6{
    -ms-flex-order:6;
    order:6;
  }
  .order-sm-7{
    -ms-flex-order:7;
    order:7;
  }
  .order-sm-8{
    -ms-flex-order:8;
    order:8;
  }
  .order-sm-9{
    -ms-flex-order:9;
    order:9;
  }
  .order-sm-10{
    -ms-flex-order:10;
    order:10;
  }
  .order-sm-11{
    -ms-flex-order:11;
    order:11;
  }
  .order-sm-12{
    -ms-flex-order:12;
    order:12;
  }
  .offset-sm-1{
    margin-left:8.333333%;
  }
  .offset-sm-2{
    margin-left:16.666667%;
  }
  .offset-sm-3{
    margin-left:25%;
  }
  .offset-sm-4{
    margin-left:33.333333%;
  }
  .offset-sm-5{
    margin-left:41.666667%;
  }
  .offset-sm-6{
    margin-left:50%;
  }
  .offset-sm-7{
    margin-left:58.333333%;
  }
  .offset-sm-8{
    margin-left:66.666667%;
  }
  .offset-sm-9{
    margin-left:75%;
  }
  .offset-sm-10{
    margin-left:83.333333%;
  }
  .offset-sm-11{
    margin-left:91.666667%;
  }
}

@media (min-width: 768px){
  .col-md{
    -ms-flex-preferred-size:0;
    flex-basis:0;
    -ms-flex-positive:1;
    flex-grow:1;
    max-width:100%;
  }
  .col-md-auto{
    -ms-flex:0 0 auto;
    flex:0 0 auto;
    width:auto;
    max-width:none;
  }
  .col-md-1{
    -ms-flex:0 0 8.333333%;
    flex:0 0 8.333333%;
    max-width:8.333333%;
  }
  .col-md-2{
    -ms-flex:0 0 16.666667%;
    flex:0 0 16.666667%;
    max-width:16.666667%;
  }
  .col-md-3{
    -ms-flex:0 0 25%;
    flex:0 0 25%;
    max-width:25%;
  }
  .col-md-4{
    -ms-flex:0 0 33.333333%;
    flex:0 0 33.333333%;
    max-width:33.333333%;
  }
  .col-md-5{
    -ms-flex:0 0 41.666667%;
    flex:0 0 41.666667%;
    max-width:41.666667%;
  }
  .col-md-6{
    -ms-flex:0 0 50%;
    flex:0 0 50%;
    max-width:50%;
  }
  .col-md-7{
    -ms-flex:0 0 58.333333%;
    flex:0 0 58.333333%;
    max-width:58.333333%;
  }
  .col-md-8{
    -ms-flex:0 0 66.666667%;
    flex:0 0 66.666667%;
    max-width:66.666667%;
  }
  .col-md-9{
    -ms-flex:0 0 75%;
    flex:0 0 75%;
    max-width:75%;
  }
  .col-md-10{
    -ms-flex:0 0 83.333333%;
    flex:0 0 83.333333%;
    max-width:83.333333%;
  }
  .col-md-11{
    -ms-flex:0 0 91.666667%;
    flex:0 0 91.666667%;
    max-width:91.666667%;
  }
  .col-md-12{
    -ms-flex:0 0 100%;
    flex:0 0 100%;
    max-width:100%;
  }
  .order-md-1{
    -ms-flex-order:1;
    order:1;
  }
  .order-md-2{
    -ms-flex-order:2;
    order:2;
  }
  .order-md-3{
    -ms-flex-order:3;
    order:3;
  }
  .order-md-4{
    -ms-flex-order:4;
    order:4;
  }
  .order-md-5{
    -ms-flex-order:5;
    order:5;
  }
  .order-md-6{
    -ms-flex-order:6;
    order:6;
  }
  .order-md-7{
    -ms-flex-order:7;
    order:7;
  }
  .order-md-8{
    -ms-flex-order:8;
    order:8;
  }
  .order-md-9{
    -ms-flex-order:9;
    order:9;
  }
  .order-md-10{
    -ms-flex-order:10;
    order:10;
  }
  .order-md-11{
    -ms-flex-order:11;
    order:11;
  }
  .order-md-12{
    -ms-flex-order:12;
    order:12;
  }
  .offset-md-1{
    margin-left:8.333333%;
  }
  .offset-md-2{
    margin-left:16.666667%;
  }
  .offset-md-3{
    margin-left:25%;
  }
  .offset-md-4{
    margin-left:33.333333%;
  }
  .offset-md-5{
    margin-left:41.666667%;
  }
  .offset-md-6{
    margin-left:50%;
  }
  .offset-md-7{
    margin-left:58.333333%;
  }
  .offset-md-8{
    margin-left:66.666667%;
  }
  .offset-md-9{
    margin-left:75%;
  }
  .offset-md-10{
    margin-left:83.333333%;
  }
  .offset-md-11{
    margin-left:91.666667%;
  }
}

@media (min-width: 992px){
  .col-lg{
    -ms-flex-preferred-size:0;
    flex-basis:0;
    -ms-flex-positive:1;
    flex-grow:1;
    max-width:100%;
  }
  .col-lg-auto{
    -ms-flex:0 0 auto;
    flex:0 0 auto;
    width:auto;
    max-width:none;
  }
  .col-lg-1{
    -ms-flex:0 0 8.333333%;
    flex:0 0 8.333333%;
    max-width:8.333333%;
  }
  .col-lg-2{
    -ms-flex:0 0 16.666667%;
    flex:0 0 16.666667%;
    max-width:16.666667%;
  }
  .col-lg-3{
    -ms-flex:0 0 25%;
    flex:0 0 25%;
    max-width:25%;
  }
  .col-lg-4{
    -ms-flex:0 0 33.333333%;
    flex:0 0 33.333333%;
    max-width:33.333333%;
  }
  .col-lg-5{
    -ms-flex:0 0 41.666667%;
    flex:0 0 41.666667%;
    max-width:41.666667%;
  }
  .col-lg-6{
    -ms-flex:0 0 50%;
    flex:0 0 50%;
    max-width:50%;
  }
  .col-lg-7{
    -ms-flex:0 0 58.333333%;
    flex:0 0 58.333333%;
    max-width:58.333333%;
  }
  .col-lg-8{
    -ms-flex:0 0 66.666667%;
    flex:0 0 66.666667%;
    max-width:66.666667%;
  }
  .col-lg-9{
    -ms-flex:0 0 75%;
    flex:0 0 75%;
    max-width:75%;
  }
  .col-lg-10{
    -ms-flex:0 0 83.333333%;
    flex:0 0 83.333333%;
    max-width:83.333333%;
  }
  .col-lg-11{
    -ms-flex:0 0 91.666667%;
    flex:0 0 91.666667%;
    max-width:91.666667%;
  }
  .col-lg-12{
    -ms-flex:0 0 100%;
    flex:0 0 100%;
    max-width:100%;
  }
  .order-lg-1{
    -ms-flex-order:1;
    order:1;
  }
  .order-lg-2{
    -ms-flex-order:2;
    order:2;
  }
  .order-lg-3{
    -ms-flex-order:3;
    order:3;
  }
  .order-lg-4{
    -ms-flex-order:4;
    order:4;
  }
  .order-lg-5{
    -ms-flex-order:5;
    order:5;
  }
  .order-lg-6{
    -ms-flex-order:6;
    order:6;
  }
  .order-lg-7{
    -ms-flex-order:7;
    order:7;
  }
  .order-lg-8{
    -ms-flex-order:8;
    order:8;
  }
  .order-lg-9{
    -ms-flex-order:9;
    order:9;
  }
  .order-lg-10{
    -ms-flex-order:10;
    order:10;
  }
  .order-lg-11{
    -ms-flex-order:11;
    order:11;
  }
  .order-lg-12{
    -ms-flex-order:12;
    order:12;
  }
  .offset-lg-1{
    margin-left:8.333333%;
  }
  .offset-lg-2{
    margin-left:16.666667%;
  }
  .offset-lg-3{
    margin-left:25%;
  }
  .offset-lg-4{
    margin-left:33.333333%;
  }
  .offset-lg-5{
    margin-left:41.666667%;
  }
  .offset-lg-6{
    margin-left:50%;
  }
  .offset-lg-7{
    margin-left:58.333333%;
  }
  .offset-lg-8{
    margin-left:66.666667%;
  }
  .offset-lg-9{
    margin-left:75%;
  }
  .offset-lg-10{
    margin-left:83.333333%;
  }
  .offset-lg-11{
    margin-left:91.666667%;
  }
}

@media (min-width: 1200px){
  .col-xl{
    -ms-flex-preferred-size:0;
    flex-basis:0;
    -ms-flex-positive:1;
    flex-grow:1;
    max-width:100%;
  }
  .col-xl-auto{
    -ms-flex:0 0 auto;
    flex:0 0 auto;
    width:auto;
    max-width:none;
  }
  .col-xl-1{
    -ms-flex:0 0 8.333333%;
    flex:0 0 8.333333%;
    max-width:8.333333%;
  }
  .col-xl-2{
    -ms-flex:0 0 16.666667%;
    flex:0 0 16.666667%;
    max-width:16.666667%;
  }
  .col-xl-3{
    -ms-flex:0 0 25%;
    flex:0 0 25%;
    max-width:25%;
  }
  .col-xl-4{
    -ms-flex:0 0 33.333333%;
    flex:0 0 33.333333%;
    max-width:33.333333%;
  }
  .col-xl-5{
    -ms-flex:0 0 41.666667%;
    flex:0 0 41.666667%;
    max-width:41.666667%;
  }
  .col-xl-6{
    -ms-flex:0 0 50%;
    flex:0 0 50%;
    max-width:50%;
  }
  .col-xl-7{
    -ms-flex:0 0 58.333333%;
    flex:0 0 58.333333%;
    max-width:58.333333%;
  }
  .col-xl-8{
    -ms-flex:0 0 66.666667%;
    flex:0 0 66.666667%;
    max-width:66.666667%;
  }
  .col-xl-9{
    -ms-flex:0 0 75%;
    flex:0 0 75%;
    max-width:75%;
  }
  .col-xl-10{
    -ms-flex:0 0 83.333333%;
    flex:0 0 83.333333%;
    max-width:83.333333%;
  }
  .col-xl-11{
    -ms-flex:0 0 91.666667%;
    flex:0 0 91.666667%;
    max-width:91.666667%;
  }
  .col-xl-12{
    -ms-flex:0 0 100%;
    flex:0 0 100%;
    max-width:100%;
  }
  .order-xl-1{
    -ms-flex-order:1;
    order:1;
  }
  .order-xl-2{
    -ms-flex-order:2;
    order:2;
  }
  .order-xl-3{
    -ms-flex-order:3;
    order:3;
  }
  .order-xl-4{
    -ms-flex-order:4;
    order:4;
  }
  .order-xl-5{
    -ms-flex-order:5;
    order:5;
  }
  .order-xl-6{
    -ms-flex-order:6;
    order:6;
  }
  .order-xl-7{
    -ms-flex-order:7;
    order:7;
  }
  .order-xl-8{
    -ms-flex-order:8;
    order:8;
  }
  .order-xl-9{
    -ms-flex-order:9;
    order:9;
  }
  .order-xl-10{
    -ms-flex-order:10;
    order:10;
  }
  .order-xl-11{
    -ms-flex-order:11;
    order:11;
  }
  .order-xl-12{
    -ms-flex-order:12;
    order:12;
  }
  .offset-xl-1{
    margin-left:8.333333%;
  }
  .offset-xl-2{
    margin-left:16.666667%;
  }
  .offset-xl-3{
    margin-left:25%;
  }
  .offset-xl-4{
    margin-left:33.333333%;
  }
  .offset-xl-5{
    margin-left:41.666667%;
  }
  .offset-xl-6{
    margin-left:50%;
  }
  .offset-xl-7{
    margin-left:58.333333%;
  }
  .offset-xl-8{
    margin-left:66.666667%;
  }
  .offset-xl-9{
    margin-left:75%;
  }
  .offset-xl-10{
    margin-left:83.333333%;
  }
  .offset-xl-11{
    margin-left:91.666667%;
  }
}

*{
  box-sizing:border-box;
  padding:0;
  margin:0;
}

*::before, *::after{
  box-sizing:border-box;
}

html{
  font-size:62.5%;
  line-height:1.6;
}

body{
  font-family:"Lato", sans-serif;
  font-size:16px;
  font-weight:400;
  color:#5f5f5f;
  background:#fafbfc;
}

main{
  display:block;
}

a{
  color:#33c3f0;
  text-decoration:none;
  background-color:transparent;
  transition:color linear 250ms;
}

a:hover{
  color:#10aee0;
  text-decoration:none;
}

button,
[type="button"],
[type="reset"],
[type="submit"]{
  -webkit-appearance:button;
}

::-moz-focus-inner{
  padding:0;
  border:0;
}

.button{
  box-sizing:border-box;
  display:inline-block;
  padding:0.8rem 1rem;
  overflow:visible;
  font-family:inherit;
  font-size:1.5rem;
  font-weight:400;
  line-height:1.5;
  color:#5f5f5f;
  text-align:center;
  text-decoration:none;
  white-space:nowrap;
  cursor:pointer;
  -webkit-user-select:none;
  -moz-user-select:none;
  -ms-user-select:none;
  user-select:none;
  background-color:white;
  border:1px solid #e6e6e6;
  border-radius:0.25rem;
  transition:background-color linear 250ms, border-color linear 250ms;
}

.button:hover, .button:focus{
  color:#5f5f5f;
  background-color:#e6e6e6;
  border-color:#cdcdcd;
  outline:0;
}

.button.button-outline{
  background-color:transparent;
  transition:background-color linear 250ms, border-color linear 250ms, color linear 250ms;
}

.button.button-outline:hover, .button.button-outline:focus{
  color:#464646;
  background-color:transparent;
  border-color:#cdcdcd;
  outline:0;
}

.button.button-clear{
  background-color:transparent;
  border-color:transparent;
  transition:background-color linear 250ms, border-color linear 250ms, color linear 250ms;
}

.button.button-clear:hover, .button.button-clear:focus{
  color:#464646;
  background-color:transparent;
  border-color:transparent;
  outline:0;
}

.button.button-primary{
  color:white;
  background-color:#33c3f0;
  border-color:#1bbcee;
}

.button.button-primary:hover, .button.button-primary:focus{
  color:white;
  background-color:#10aee0;
  border-color:#0f9cc8;
  outline:0;
}

.button.button-outline.button-primary{
  color:#33c3f0;
  background-color:transparent;
  border-color:#33c3f0;
}

.button.button-outline.button-primary:hover, .button.button-outline.button-primary:focus{
  color:#10aee0;
  background-color:transparent;
  border-color:#10aee0;
  outline:0;
}

.button.button-clear.button-primary{
  color:#33c3f0;
  background-color:transparent;
  border-color:transparent;
}

.button.button-clear.button-primary:hover, .button.button-clear.button-primary:focus{
  color:#10aee0;
  background-color:transparent;
  border-color:transparent;
  outline:0;
}

.button.button-secondary{
  color:#111111;
  background-color:#f0f0f0;
  border-color:#e3e3e3;
}

.button.button-secondary:hover, .button.button-secondary:focus{
  color:#111111;
  background-color:#d7d7d7;
  border-color:#cacaca;
  outline:0;
}

.button.button-outline.button-secondary{
  color:#f0f0f0;
  background-color:transparent;
  border-color:#f0f0f0;
}

.button.button-outline.button-secondary:hover, .button.button-outline.button-secondary:focus{
  color:#d7d7d7;
  background-color:transparent;
  border-color:#d7d7d7;
  outline:0;
}

.button.button-clear.button-secondary{
  color:#f0f0f0;
  background-color:transparent;
  border-color:transparent;
}

.button.button-clear.button-secondary:hover, .button.button-clear.button-secondary:focus{
  color:#d7d7d7;
  background-color:transparent;
  border-color:transparent;
  outline:0;
}

code,
kbd,
pre,
samp{
  font-family:"Inconsolata", monospace;
}

code{
  padding:0.2rem 0.5rem;
  font-size:100%;
  color:#5f5f5f;
  word-break:break-word;
  background:#e7eaeb;
  border:1px solid #e6e6e6;
  border-radius:0.25rem;
}

pre{
  display:block;
  padding:2rem;
  margin-bottom:2.5rem;
  overflow-x:auto;
  font-size:90%;
  color:#5f5f5f;
  white-space:pre;
  background:#e7eaeb;
  border:1px solid #e6e6e6;
  border-radius:0.25rem;
}

pre code{
  font-size:inherit;
  color:inherit;
  word-break:normal;
}

*[disabled]{
  cursor:not-allowed;
}

form{
  margin-bottom:2.5rem;
}

input[type="date"], input[type="datetime"], input[type="datetime-local"], input[type="email"], input[type="month"], input[type="number"], input[type="password"], input[type="search"], input[type="tel"], input[type="text"], input[type="url"], input[type="week"]{
  box-sizing:border-box;
  margin-bottom:1.5rem;
  font-family:inherit;
  line-height:1.5;
  color:#5f5f5f;
  background:white;
  border:1px solid #e6e6e6;
  border-radius:0.25rem;
  box-shadow:none;
  transition:background linear 250ms, border-color linear 250ms;
  padding:0.8rem 1rem;
  font-size:1.5rem;
  max-width:100%;
  -webkit-appearance:none;
}

input[type="date"]:focus, input[type="datetime"]:focus, input[type="datetime-local"]:focus, input[type="email"]:focus, input[type="month"]:focus, input[type="number"]:focus, input[type="password"]:focus, input[type="search"]:focus, input[type="tel"]:focus, input[type="text"]:focus, input[type="url"]:focus, input[type="week"]:focus{
  background:white;
  border-color:#33c3f0;
  outline:0;
}

input[type="date"], input[type="datetime"], input[type="datetime-local"], input[type="month"], input[type="week"]{
  -webkit-appearance:listbox;
  height:calc(3.85rem + 2px);
}

input[type="checkbox"], input[type="radio"]{
  margin-right:1rem;
}

::-webkit-inner-spin-button,
::-webkit-outer-spin-button{
  height:auto;
}

::-webkit-datetime-edit-fields-wrapper{
  padding:0;
  margin:0;
}

::-webkit-input-placeholder{
  color:#b9b9b9;
  opacity:1;
}

::-moz-placeholder{
  color:#b9b9b9;
  opacity:1;
}

:-ms-input-placeholder{
  color:#b9b9b9;
  opacity:1;
}

::-ms-input-placeholder{
  color:#b9b9b9;
  opacity:1;
}

::placeholder{
  color:#b9b9b9;
  opacity:1;
}

textarea{
  box-sizing:border-box;
  margin-bottom:1.5rem;
  font-family:inherit;
  line-height:1.5;
  color:#5f5f5f;
  background:white;
  border:1px solid #e6e6e6;
  border-radius:0.25rem;
  box-shadow:none;
  transition:background linear 250ms, border-color linear 250ms;
  padding:0.8rem 1rem;
  font-size:1.5rem;
  max-width:100%;
  -webkit-appearance:none;
  overflow:auto;
}

textarea:focus{
  background:white;
  border-color:#33c3f0;
  outline:0;
}

select{
  box-sizing:border-box;
  margin-bottom:1.5rem;
  font-family:inherit;
  line-height:1.5;
  color:#5f5f5f;
  background:white;
  border:1px solid #e6e6e6;
  border-radius:0.25rem;
  box-shadow:none;
  transition:background linear 250ms, border-color linear 250ms;
  padding:0.8rem 1rem;
  font-size:1.5rem;
  max-width:100%;
  text-transform:none;
}

select:focus{
  background:white;
  border-color:#33c3f0;
  outline:0;
}

select:not([multiple]){
  height:calc(3.85rem + 2px);
}

label{
  display:block;
  margin-bottom:.5rem;
  font-weight:600;
}

legend{
  box-sizing:border-box;
  display:block;
  max-width:100%;
  margin-bottom:.5rem;
  font-weight:600;
  color:inherit;
  white-space:normal;
}

fieldset{
  margin-bottom:1.5rem;
  border-width:0;
}

hr{
  box-sizing:content-box;
  height:0;
  margin:1.5rem 0;
  overflow:visible;
  border:0;
  border-top:1px solid #e6e6e6;
}

img{
  border-style:none;
}

figcaption{
  display:block;
}

figure{
  display:block;
  margin:0 0 2.5rem;
}

ul{
  padding-left:2rem;
  margin-bottom:2.5rem;
  list-style:circle outside;
}

ul ul,
ul ol{
  margin:0;
}

ol{
  padding-left:1.7rem;
  margin-bottom:2.5rem;
  list-style:decimal outside;
}

ol ol,
ol ul{
  margin:0;
}

dl{
  margin-bottom:2.5rem;
}

dl dt{
  margin:0 0 0 0;
  font-weight:600;
}

dl dd{
  margin:0 0 2.5rem 2.5rem;
}

table{
  width:100%;
  max-width:100%;
  margin-bottom:2.5rem;
  font-size:90%;
  border-spacing:0;
  border-collapse:collapse;
  background-color:transparent;
}

caption{
  padding:0.85rem 0.85rem;
}

th{
  padding:0.85rem 0.85rem;
  text-align:left;
  vertical-align:top;
}

td{
  padding:0.85rem 0.85rem;
  text-align:left;
  vertical-align:top;
  border-top:1px solid #e6e6e6;
}

.table-bordered, table.docutils:not(.footnote):not(.citation), table.docutils.field-list{
  border:solid 1px #e6e6e6;
}

.table-headed th, table.docutils:not(.footnote):not(.citation) th, table.docutils.field-list th{
  background-color:#e7e9ec;
}

.table-striped tbody tr:nth-child(odd), table.docutils:not(.footnote):not(.citation) tbody tr:nth-child(odd){
  background-color:#fafafa;
}

.table-hover tbody tr:hover{
  background-color:whitesmoke;
}

h1, #search-results h2, #search-results .document > .section .toctree-wrapper .caption, .document > .section .toctree-wrapper #search-results .caption,
.h1, h2, .document > .section .toctree-wrapper .caption,
.h2, h3, #search-results ul.search > li > a,
.h3, h4,
.h4, h5,
.h5, h6,
.h6{
  font-family:"Lato", sans-serif;
  color:#5f5f5f;
}

h1 small, #search-results h2 small, #search-results .document > .section .toctree-wrapper .caption small, .document > .section .toctree-wrapper #search-results .caption small, .h1 small, h2 small, .document > .section .toctree-wrapper .caption small, .h2 small, h3 small, #search-results ul.search > li > a small, .h3 small, h4 small, .h4 small, h5 small, .h5 small, h6 small, .h6 small{
  font-size:65%;
  line-height:1;
}

h1, #search-results h2, #search-results .document > .section .toctree-wrapper .caption, .document > .section .toctree-wrapper #search-results .caption,
.h1{
  margin:4rem 0 1.5rem;
  font-size:32px;
  font-weight:700;
  line-height:1.2;
}

h2, .document > .section .toctree-wrapper .caption,
.h2{
  margin:4rem 0 1.5rem;
  font-size:24px;
  font-weight:700;
  line-height:1.25;
}

h3, #search-results ul.search > li > a,
.h3{
  margin:4rem 0 1.5rem;
  font-size:20.8px;
  font-weight:700;
  line-height:1.3;
}

h4,
.h4{
  margin:4rem 0 1.5rem;
  font-size:17.6px;
  font-weight:700;
  line-height:1.35;
}

h5,
.h5{
  margin:4rem 0 1.5rem;
  font-size:16px;
  font-weight:700;
  line-height:1.5;
}

h6,
.h6{
  margin:4rem 0 1.5rem;
  font-size:14.4px;
  font-weight:700;
  line-height:1.6;
}

abbr[title]{
  -webkit-text-decoration:underline dotted;
  text-decoration:underline dotted;
}

p{
  margin-bottom:2.5rem;
}

blockquote{
  padding:1rem 1.5rem;
  margin-bottom:2.5rem;
  border-left:3px solid #e6e6e6;
}

b,
strong{
  font-weight:700;
}

small{
  font-size:80%;
}

sub,
sup{
  position:relative;
  font-size:75%;
  line-height:0;
  vertical-align:baseline;
}

sub{
  bottom:-.25em;
}

sup{
  top:-.5em;
}
.alert, .admonition{
  position:relative;
  padding:1.5rem 2rem;
  margin-bottom:2.5rem;
  border:1px solid #e6e6e6;
  border-radius:0.25rem;
}
.alert-green, .admonition.important, .admonition.hint, .admonition.tip{
  background:#bcf0c2;
  border:1px solid #a8ebaf;
  color:#5f5f5f;
}

.alert-red, .admonition.danger, .admonition.error{
  background:#ffd2cf;
  border:1px solid #ffbab6;
  color:#5f5f5f;
}

.alert-blue, .admonition.note{
  background:#ccf1ff;
  border:1px solid #b2e9ff;
  color:#5f5f5f;
}

.alert-orange, .admonition.attention, .admonition.caution, .admonition.warning{
  background:#ffe5ce;
  border:1px solid #ffd7b4;
  color:#5f5f5f;
}

.icon-input{
  max-width:100%;
  display:-ms-inline-flexbox;
  display:inline-flex;
  font-size:1.5rem;
  margin-bottom:1.5rem;
  position:relative;
}

.icon-input input{
  -ms-flex:1 1 auto;
  flex:1 1 auto;
  font-size:1em;
  margin:0;
  padding-right:2.65em;
}

.icon-input [class*="icon-"]{
  position:absolute;
  top:0;
  right:0;
  bottom:auto;
  left:auto;
  color:#b9b9b9;
  height:100%;
  font-size:1em;
  line-height:1;
  opacity:1;
  pointer-events:none;
  text-align:center;
  width:2.65em;
}

.icon-input [class*="icon-"]:before{
  position:absolute;
  top:50%;
  right:auto;
  bottom:auto;
  left:0;
  margin:-.5em 0;
  text-align:center;
  width:100%;
}
@font-face{
  font-family:'fontello';
  src:url("../font/fontello.eot?44759829");
  src:url("../font/fontello.eot?44759829#iefix") format("embedded-opentype"), url("../font/fontello.woff2?44759829") format("woff2"), url("../font/fontello.woff?44759829") format("woff"), url("../font/fontello.ttf?44759829") format("truetype"), url("../font/fontello.svg?44759829#fontello") format("svg");
  font-weight:normal;
  font-style:normal;
}
[class^="icon-"]:before, [class*=" icon-"]:before{
  font-family:"fontello";
  font-style:normal;
  font-weight:normal;
  speak:none;
  display:inline-block;
  text-decoration:inherit;
  width:1em;
  margin-right:.2em;
  text-align:center;
  font-variant:normal;
  text-transform:none;
  line-height:1em;
  margin-left:.2em;
  -webkit-font-smoothing:antialiased;
  -moz-osx-font-smoothing:grayscale;
}

.icon-search:before{
  content:'\e800';
}
.icon-edit:before{
  content:'\e801';
}
.icon-download:before{
  content:'\e802';
}
.icon-attention:before{
  content:'\e804';
}
.icon-info-circled:before{
  content:'\e805';
}
.icon-attention-circled:before{
  content:'\e810';
}
.icon-github-circled:before{
  content:'\f09b';
}
.icon-menu:before{
  content:'\f0c9';
}
.icon-lightbulb:before{
  content:'\f0eb';
}
.icon-bitbucket:before{
  content:'\f171';
}
.icon-gitlab:before{
  content:'\f296';
}
.admonition .admonition-title{
  font-weight:bold;
  margin-bottom:.5rem;
}

.admonition .admonition-title:before{
  font-family:"fontello";
  padding-right:1rem;
}

.admonition :last-child{
  margin-bottom:0;
}

.admonition.attention .admonition-title:before, .admonition.caution .admonition-title:before, .admonition.warning .admonition-title:before{
  content:"\e804";
}

.admonition.danger .admonition-title:before, .admonition.error .admonition-title:before{
  content:"\e810";
}

.admonition.important .admonition-title:before{
  content:"\e810";
}

.admonition.hint .admonition-title:before, .admonition.tip .admonition-title:before{
  content:"\f0eb";
}

.admonition.note .admonition-title:before{
  content:"\e801";
}
.breadcrumbs-outer{
  background:#fafbfc;
  border:solid 1px #e6e6e6;
}

.breadcrumbs{
  display:-ms-flexbox;
  display:flex;
  list-style:none;
  margin:0;
  padding:1rem 0;
}

.breadcrumbs li + li:not(.breadcrumbs-aside):before{
  padding:0 1rem;
  content:"•";
}

.breadcrumbs .breadcrumbs-aside{
  margin-left:auto;
}

.breadcrumbs code{
  padding:0;
  border:none;
  background:none;
  font-family:"Lato", sans-serif;
  font-size:initial;
}

.breadcrumbs code.literal{
  color:#5f5f5f;
}

@media (max-width: 991px){
  ul.breadcrumbs .breadcrumbs-aside{
    display:none;
  }
}
.footer{
  color:rgba(0, 0, 0, 0.54);
  padding-top:4rem;
  padding-bottom:4rem;
}
header{
  background:#24292e;
  padding:2rem 0;
}

header .container{
  display:-ms-flexbox;
  display:flex;
  -ms-flex-direction:row;
  flex-direction:row;
  -ms-flex-align:center;
  align-items:center;
}

header .site-nav-toggle{
  color:#f5f6f7;
  font-size:3.5rem;
  margin-left:-1rem;
  padding:.5rem 1rem .5rem 0;
  cursor:pointer;
}

header .site-title{
  color:white;
  font-size:2rem;
  font-weight:400;
}

@media (max-width: 991px){
  header{
    position:fixed;
    top:0;
    right:auto;
    bottom:auto;
    left:auto;
    padding:0;
    -webkit-transform:translateY(0);
    transform:translateY(0);
    transition:-webkit-transform 250ms ease-in-out;
    transition:transform 250ms ease-in-out;
    transition:transform 250ms ease-in-out, -webkit-transform 250ms ease-in-out;
    width:100%;
    z-index:101;
  }
  header.up{
    -webkit-transform:translateY(-100%);
    transform:translateY(-100%);
  }
  header .site-title{
    font-size:1.5rem;
  }
}
.main-outer{
  background:#f5f6f7;
  padding-top:3rem;
  padding-bottom:10rem;
}

.document > .section > h1, #search-results .document > .section > h2, #search-results .document > .section .toctree-wrapper .document > .section > .caption, .document > .section .toctree-wrapper #search-results .document > .section > .caption{
  margin-top:0;
  margin-bottom:4rem;
}
.site-nav code.literal,
.site-nav tt.literal{
  border:none;
  background:inherit;
  color:inherit;
  padding-left:0;
  padding-right:0;
}

.site-nav-tree .caption{
  font-weight:bold;
}

.site-nav-tree ul{
  list-style-type:none;
  padding-left:0;
}

.site-nav-tree ul ul{
  margin-left:1.5rem;
}

.site-nav-tree li{
  line-height:1.8;
}

.site-nav-tree > ul > li:not(.current) > ul{
  display:none;
}

.site-nav-tree a{
  color:rgba(0, 0, 0, 0.54);
}

.site-nav-tree a.current, .site-nav-tree a:hover{
  color:rgba(0, 0, 0, 0.87);
}

@media (max-width: 991px){
  body{
    padding-top:6.6rem;
  }
  .main-outer{
    position:relative;
  }
  .site-nav{
    position:fixed;
    top:0;
    right:0;
    bottom:0;
    left:0;
    background:#f5f6f7;
    height:100vh;
    overflow-y:scroll;
    padding-top:10rem;
    -webkit-transform:translateX(-100%);
    transform:translateX(-100%);
    transition:-webkit-transform 250ms linear;
    transition:transform 250ms linear;
    transition:transform 250ms linear, -webkit-transform 250ms linear;
    z-index:100;
  }
  body.nav-in{
    overflow:hidden;
  }
  body.nav-in .site-nav{
    -webkit-transform:translateX(0);
    transform:translateX(0);
  }
  body.nav-in .site-nav .icon-input{
    width:100%;
  }
}
.docutils.container{
  width:100%;
  margin:0;
  padding:0;
}
#search-results h2, #search-results .document > .section .toctree-wrapper .caption, .document > .section .toctree-wrapper #search-results .caption{
  margin-bottom:5rem;
}

#search-results ul.search{
  list-style-type:none;
  margin-top:3rem;
  padding:0;
}

#search-results ul.search > li:not(:last-child){
  padding-bottom:3rem;
  border-bottom:solid 1px #e6e6e6;
  margin-bottom:3rem;
}
.headerlink{
  visibility:hidden;
  padding-left:.5rem;
  opacity:.3;
}

.headerlink:hover{
  opacity:.6;
}

caption:hover > a.headerlink,
.code-block-caption:hover > a.headerlink,
dt:hover > a.headerlink,
h1:hover > a.headerlink,
#search-results h2:hover > a.headerlink,
#search-results .document > .section .toctree-wrapper .caption:hover > a.headerlink,
.document > .section .toctree-wrapper #search-results .caption:hover > a.headerlink,
h2:hover > a.headerlink,
.document > .section .toctree-wrapper .caption:hover > a.headerlink,
h3:hover > a.headerlink,
#search-results ul.search > li > a:hover > a.headerlink,
h4:hover > a.headerlink,
h5:hover > a.headerlink,
h6:hover > a.headerlink,
.caption:hover > a.headerlink,
.caption-text:hover > a.headerlink{
  visibility:visible;
}

.footnote-reference,
.citation-reference{
  font-size:90%;
  position:relative;
  top:-.6rem;
}

.rubric{
  margin-bottom:1.25rem;
  font-weight:bold;
}

img{
  min-height:1px;
  max-width:100%;
  height:auto;
}

.align-left{
  float:left;
  margin-right:2.5rem;
  margin-bottom:2.5rem;
}

.align-center{
  margin:auto;
  display:block;
}

.align-center.figure{
  text-align:center;
}

.align-right{
  float:right;
  margin-left:2.5rem;
  margin-bottom:2.5rem;
}
.sidebar{
  border:1px solid #e6e6e6;
  margin:0 0 2.5rem 2.5rem;
  padding:2.5rem;
  background-color:#f0f0f0;
  width:40%;
  float:right;
}

.sidebar-title{
  background:#f5f6f7;
  font-weight:bold;
  margin-top:-2.5rem;
  margin-right:-2.5rem;
  margin-bottom:2.5rem;
  margin-left:-2.5rem;
  padding:.5rem 1rem;
}
table.docutils.footnote{
  color:#aaaaaa;
  width:auto;
}

table.docutils.footnote td{
  border:0;
  padding-left:0;
  padding-right:2rem;
}

table.docutils.footnote td:not(.label){
  width:100%;
}

table.docutils.footnote td em + p{
  display:inline-block;
}

table.docutils.footnote td p.last{
  margin-bottom:0;
}
.figure p.caption{
  font-style:italic;
}
ol.arabic{
  list-style-type:decimal;
}

ol.loweralpha{
  list-style-type:lower-alpha;
}

ol.upperalpha{
  list-style-type:upper-alpha;
}

ol.lowerroman{
  list-style-type:lower-roman;
}

ol.upperroman{
  list-style-type:upper-roman;
}

li p,
dd p{
  margin-bottom:1.25rem;
}

li p:last-child,
dd p:last-child{
  margin-bottom:0;
}

.line-block{
  margin-bottom:2.5rem;
  margin-left:2.5rem;
}

.line-block .line-block{
  margin-bottom:0;
  margin-left:2rem;
}

blockquote .attribution{
  margin-bottom:0;
}

.guilabel{
  border:1px solid #33c3f0;
  background:#c2edfa;
  font-size:80%;
  font-weight:700;
  border-radius:0.25rem;
  padding:.15rem .5rem;
  margin:auto .2rem;
}
div[class^='highlight-']{
  background:#e7eaeb;
  margin-bottom:2.5rem;
  overflow-x:auto;
}

div[class^='highlight-'] pre{
  margin-bottom:0;
}

td.linenos pre{
  margin:0;
  border:0;
  border-radius:0;
  border-right:1px solid #e6e6e6;
}

td.code{
  width:100%;
}

td.code pre{
  margin:0;
  border:0;
  border-radius:0;
}

table.highlighttable{
  font-size:100%;
  border:1px solid #e6e6e6;
  border-radius:0.25rem;
  margin-bottom:0;
}

table.highlighttable td{
  padding:0;
}

tt.literal,
code.literal{
  background:white;
  color:#ff4136;
  font-size:90%;
}

tt.xref,
a tt,
code.xref,
a code{
  color:#111111;
}

tt.download,
code.download{
  background:inherit;
  padding:inherit;
  font-weight:normal;
  font-family:inherit;
  font-size:inherit;
  color:inherit;
  border:inherit;
  white-space:inherit;
}

tt.download::before,
code.download::before{
  font-family:fontello;
  content:"\e802";
  padding-right:.5rem;
}
dl:not(.docutils) dt{
  margin:.6rem 0;
  font-size:90%;
  line-height:normal;
  background:rgba(51, 195, 240, 0.1);
  color:rgba(51, 195, 240, 0.9);
  border-top:solid 3px #33c3f0;
  padding:.6rem;
}

dl:not(.docutils) dl dt{
  border:none;
  border-left:solid 3px #e6e6e6;
  background:#f0f0f0;
  color:#5f5f5f;
}

dl:not(.docutils) tt.descname,
dl:not(.docutils) tt.descclassname,
dl:not(.docutils) code.descname,
dl:not(.docutils) code.descclassname{
  background-color:transparent;
  border:none;
  padding:0;
  font-size:100%;
}

dl:not(.docutils) tt.descname,
dl:not(.docutils) code.descname{
  font-weight:bold;
}

dl:not(.docutils).data dt{
  display:inline-block;
}
.align-top{
  vertical-align:top;
}

.align-bottom{
  vertical-align:bottom;
}

.align-middle{
  vertical-align:middle;
}

.align-baseline{
  vertical-align:baseline;
}

.clearfix::after{
  display:block;
  clear:both;
  content:"";
}

.b-white{
  background-color:white;
}

.c-white{
  color:white;
}

.b-black{
  background-color:#111111;
}

.c-black{
  color:#111111;
}

.b-primary{
  background-color:#33c3f0;
}

.c-primary{
  color:#33c3f0;
}

.b-secondary{
  background-color:#f0f0f0;
}

.c-secondary{
  color:#f0f0f0;
}

.b-aqua{
  background-color:#7fdbff;
}

.c-aqua{
  color:#7fdbff;
}

.b-blue{
  background-color:#0074d9;
}

.c-blue{
  color:#0074d9;
}

.b-navy{
  background-color:#001f3f;
}

.c-navy{
  color:#001f3f;
}

.b-teal{
  background-color:#39cccc;
}

.c-teal{
  color:#39cccc;
}

.b-green{
  background-color:#2ecc40;
}

.c-green{
  color:#2ecc40;
}

.b-olive{
  background-color:#3d9970;
}

.c-olive{
  color:#3d9970;
}

.b-lime{
  background-color:#01ff70;
}

.c-lime{
  color:#01ff70;
}

.b-yellow{
  background-color:#ffdc00;
}

.c-yellow{
  color:#ffdc00;
}

.b-orange{
  background-color:#ff851b;
}

.c-orange{
  color:#ff851b;
}

.b-red{
  background-color:#ff4136;
}

.c-red{
  color:#ff4136;
}

.b-fuchsia{
  background-color:#f012be;
}

.c-fuchsia{
  color:#f012be;
}

.b-purple{
  background-color:#b10dc9;
}

.c-purple{
  color:#b10dc9;
}

.b-maroon{
  background-color:#85144b;
}

.c-maroon{
  color:#85144b;
}

.b-silver{
  background-color:#dddddd;
}

.c-silver{
  color:#dddddd;
}

.b-gray{
  background-color:#aaaaaa;
}

.c-gray{
  color:#aaaaaa;
}

.b-facebook{
  background-color:#3b5999;
}

.c-facebook{
  color:#3b5999;
}

.b-twitter{
  background-color:#55acee;
}

.c-twitter{
  color:#55acee;
}

.b-linkedin{
  background-color:#0077b5;
}

.c-linkedin{
  color:#0077b5;
}

.b-googleplus{
  background-color:#dd4b39;
}

.c-googleplus{
  color:#dd4b39;
}

.b-instagram{
  background-color:#e4405f;
}

.c-instagram{
  color:#e4405f;
}

.b-pinterest{
  background-color:#bd081c;
}

.c-pinterest{
  color:#bd081c;
}

.b-cinder{
  background-color:#24292e;
}

.c-cinder{
  color:#24292e;
}

.b-whitesmoke{
  background-color:#f5f6f7;
}

.c-whitesmoke{
  color:#f5f6f7;
}

.b-solitude{
  background-color:#fafbfc;
}

.c-solitude{
  color:#fafbfc;
}

.disabled{
  cursor:not-allowed;
}

.move{
  cursor:move;
}

.pointer{
  cursor:pointer;
}

.d-block{
  display:block;
}

.d-hidden{
  display:none !important;
}

.d-flex{
  display:-ms-flexbox;
  display:flex;
}

.d-grid{
  display:grid;
}

.d-inline{
  display:inline;
}

.d-inline-block{
  display:inline-block;
}

.d-inline-flex{
  display:-ms-inline-flexbox;
  display:inline-flex;
}

.d-table{
  display:table;
}

.d-table-cell{
  display:table-cell;
}

.flex-row{
  -ms-flex-direction:row;
  flex-direction:row;
}

.flex-column{
  -ms-flex-direction:column;
  flex-direction:column;
}

.flex-row-reverse{
  -ms-flex-direction:row-reverse;
  flex-direction:row-reverse;
}

.flex-column-reverse{
  -ms-flex-direction:column-reverse;
  flex-direction:column-reverse;
}

.justify-content-start{
  -ms-flex-pack:start;
  justify-content:flex-start;
}

.justify-content-end{
  -ms-flex-pack:end;
  justify-content:flex-end;
}

.justify-content-center{
  -ms-flex-pack:center;
  justify-content:center;
}

.justify-content-between{
  -ms-flex-pack:justify;
  justify-content:space-between;
}

.justify-content-around{
  -ms-flex-pack:distribute;
  justify-content:space-around;
}

.align-items-start{
  -ms-flex-align:start;
  align-items:flex-start;
}

.align-items-end{
  -ms-flex-align:end;
  align-items:flex-end;
}

.align-items-center{
  -ms-flex-align:center;
  align-items:center;
}

.align-items-baseline{
  -ms-flex-align:baseline;
  align-items:baseline;
}

.align-items-stretch{
  -ms-flex-align:stretch;
  align-items:stretch;
}

.flex-nowrap{
  -ms-flex-wrap:nowrap;
  flex-wrap:nowrap;
}

.flex-wrap{
  -ms-flex-wrap:wrap;
  flex-wrap:wrap;
}

.flex-wrap-reverse{
  -ms-flex-wrap:wrap-reverse;
  flex-wrap:wrap-reverse;
}

.align-self-start{
  -ms-flex-item-align:start;
  align-self:flex-start;
}

.align-self-end{
  -ms-flex-item-align:end;
  align-self:flex-end;
}

.align-self-center{
  -ms-flex-item-align:center;
  align-self:center;
}

.align-self-baseline{
  -ms-flex-item-align:baseline;
  align-self:baseline;
}

.align-self-stretch{
  -ms-flex-item-align:stretch;
  align-self:stretch;
}

.pull-left{
  float:left !important;
}

.pull-right{
  float:right !important;
}

.img-fluid{
  display:block;
  width:100%;
  max-width:100%;
  height:auto;
  min-height:1px;
}

.list-style-none{
  list-style:none !important;
}

.list-style-reset{
  padding:0;
  margin:0;
  list-style:none !important;
}

.scroll-x{
  overflow-x:auto;
}

.noscroll{
  overflow:hidden;
}

.fixed{
  position:fixed;
}

.relative{
  position:relative;
}

.absolute{
  position:absolute;
}

@media print{
  .no-print,
  .no-print *{
    display:none !important;
  }
}

.full-height{
  height:100%;
}

.full-visual-height{
  height:100vh;
}

.full-width{
  box-sizing:border-box;
  width:100%;
}

.max-full-width{
  box-sizing:border-box;
  max-width:100%;
}

.margin-zero{
  margin:0;
}

.m-auto{
  margin:auto;
}

.mt-auto{
  margin-top:auto;
}

.mr-auto{
  margin-right:auto;
}

.mb-auto{
  margin-bottom:auto;
}

.ml-auto{
  margin-left:auto;
}

.push-auto{
  margin-right:auto;
  margin-left:auto;
}

.text-left{
  text-align:left;
}

.text-right{
  text-align:right;
}

.text-center{
  text-align:center;
}

.text-just{
  text-align:justify;
}

.strong{
  font-weight:700;
}

.lead{
  font-weight:300;
}

.muted{
  opacity:.7;
}

.nowrap{
  white-space:nowrap;
}

.small{
  font-size:80%;
}

.uppercase{
  text-transform:uppercase;
}

.text-shadow{
  text-shadow:0 2px 4px rgba(0, 0, 0, 0.5);
}

.flip-x{
  -webkit-transform:scale(-1, 1);
  transform:scale(-1, 1);
}

.flip-y{
  -webkit-transform:scale(1, -1);
  transform:scale(1, -1);
}

.flip-both{
  -webkit-transform:scale(-1, -1);
  transform:scale(-1, -1);
}

.hidden-xs-up{
  display:none !important;
}

@media (max-width: 575px){
  .hidden-xs-down{
    display:none !important;
  }
}

@media (min-width: null) and (max-width: 575px){
  .hidden-xs{
    display:none !important;
  }
}

@media (min-width: 576px){
  .hidden-sm-up{
    display:none !important;
  }
}

@media (max-width: 767px){
  .hidden-sm-down{
    display:none !important;
  }
}

@media (min-width: 576px) and (max-width: 767px){
  .hidden-sm{
    display:none !important;
  }
}

@media (min-width: 768px){
  .hidden-md-up{
    display:none !important;
  }
}

@media (max-width: 991px){
  .hidden-md-down{
    display:none !important;
  }
}

@media (min-width: 768px) and (max-width: 991px){
  .hidden-md{
    display:none !important;
  }
}

@media (min-width: 992px){
  .hidden-lg-up{
    display:none !important;
  }
}

@media (max-width: 1199px){
  .hidden-lg-down{
    display:none !important;
  }
}

@media (min-width: 992px) and (max-width: 1199px){
  .hidden-lg{
    display:none !important;
  }
}

@media (min-width: 1200px){
  .hidden-xl-up{
    display:none !important;
  }
}

.hidden-xl-down{
  display:none !important;
}

@media (min-width: 1200px) and (max-width: null){
  .hidden-xl{
    display:none !important;
  }
}
/*# sourceMappingURL=theme.css.map */